@@ -39,6 +39,7 @@ class VanillaTor(nettest.NetTestCase):
 
     def setUp(self):
         self.tor_progress = 0
+        self.tor_details = onion.get_tor_details()
         self.timeout = int(self.localOptions['timeout'])
 
         fd, self.tor_logfile = tempfile.mkstemp()
@@ -49,7 +50,7 @@ class VanillaTor(nettest.NetTestCase):
         self.report['success'] = None
         self.report['timeout'] = self.timeout
         self.report['transport_name'] = 'vanilla'
-        self.report['tor_version'] = str(onion.tor_details['version'])
+        self.report['tor_version'] = str(self.tor_details['version'])
         self.report['tor_progress'] = 0
         self.report['tor_progress_tag'] = None
         self.report['tor_progress_summary'] = None
@@ -73,7 +74,8 @@ class VanillaTor(nettest.NetTestCase):
             self.report['tor_progress_tag'] = tag
             self.report['tor_progress_summary'] = summary
 
-        d = txtorcon.launch_tor(config, reactor, timeout=self.timeout,
+        d = txtorcon.launch_tor(config, reactor, tor_binary=onion.find_tor_binary(),
+                                timeout=self.timeout,
                                 progress_updates=updates)
 
         @d.addCallback
