@@ -1,6 +1,7 @@
 # -*- encoding: utf-8 -*-
 
 import csv
+import random
 from urlparse import urlparse
 
 from twisted.internet import defer
@@ -36,6 +37,10 @@ class UsageOptions(usage.Options):
         ['retries', 'r', 1, 'Number of retries for the HTTP request'],
         ['timeout', 't', 240, 'Total timeout for this test'],
     ]
+    optFlags = [
+        ['no-shuffle', '', 'Disable shuffling of URLs'],
+        ['no-http', '', 'Disable testing also http for https sites specified in the test list (i.e. if you specify `-u <URL>` _only_ that <URL> will be tested)'],
+    ]
 
 
 class WebConnectivityTest(httpt.HTTPTest, dnst.DNSTest):
@@ -48,7 +53,7 @@ class WebConnectivityTest(httpt.HTTPTest, dnst.DNSTest):
                    "connect to the resolved IPs and then fetching the page "
                    "and comparing all these results with those of a control.")
     author = "Arturo Filastò"
-    version = "0.3.0"
+    version = "0.3.2"
 
     contentDecoders = [('gzip', GzipDecoder)]
 
@@ -123,10 +128,17 @@ class WebConnectivityTest(httpt.HTTPTest, dnst.DNSTest):
             else:
                 fh.seek(0)
                 generator = simple_file_generator(fh)
+            if self.localOptions['no-shuffle'] != True:
+                input_list = list(generator)
+                random.shuffle(input_list)
+                generator = input_list
+
             for i in generator:
                 if (not i.startswith("http://") and
                         not i.startswith("https://")):
                     i = "http://{}/".format(i)
+                if i.startswith('https://') and self.localOptions['no-http'] != True:
+                    yield 'http'+i[5:]
                 yield i
         finally:
             fh.close()
