@@ -26,8 +26,8 @@ class Options(usage.Options):
     optFlags = [["help", "h"],
                 ["no-collector", "n", "Disable writing to collector"],
                 ["no-njson", "N", "Disable writing to disk"],
-                ["no-geoip", "g", "Disable geoip lookup on start. "
-                                  "With this option your IP address can be disclosed in the report."],
+                ["no-geoip", "g", "Don't include geoip related information inside of the report."
+                                  "Note: Even with this option your IP address can be disclosed in the report."],
                 ["list", "s", "List the currently installed ooniprobe "
                               "nettests"],
                 ["verbose", "v", "Show more verbose information"],
