@@ -98,15 +98,17 @@ def find_pt_executable(name):
             return bin_loc
     return None
 
-tor_details = {
-    'binary': find_tor_binary(),
-    'version': tor_version()
-}
+def get_tor_details():
+    return {
+        'binary': find_tor_binary(),
+        'version': tor_version()
+    }
 
-obfsproxy_details = {
-    'binary': find_executable('obfsproxy'),
-    'version': obfsproxy_version()
-}
+def get_obfsproxy_details():
+    return {
+        'binary': find_executable('obfsproxy'),
+        'version': obfsproxy_version()
+    }
 
 transport_bin_name = { 'fte': 'fteproxy',
                        'scramblesuit': 'obfsproxy',
@@ -148,6 +150,9 @@ class OutdatedTor(Exception):
     pass
 
 def bridge_line(transport, log_file):
+    obfsproxy_details = get_obfsproxy_details()
+    tor_details = get_tor_details()
+
     bin_name = transport_bin_name.get(transport)
     if not bin_name:
         raise UnrecognizedTransport
@@ -337,6 +342,7 @@ class TorLauncherWithRetries(object):
         self.started.callback(state)
 
     def _setup_failed(self, failure):
+        log.msg("Starting Tor failed: {}".format(failure.value))
         self.tor_output.seek(0)
         map(log.debug, self.tor_output.readlines())
         self.tor_output.seek(0)
@@ -378,12 +384,15 @@ class TorLauncherWithRetries(object):
         log.debug("Building a TorState")
         config.tor.protocol = proto
         state = TorState(proto.tor_protocol)
-        state.post_bootstrap.addCallbacks(self._state_complete,
-                                          self._setup_failed)
+        # note that errors from _state_complete will only get handled
+        # if we add the errback *after* -- which is why this isn't
+        # using .addCallbacks(..)
+        state.post_bootstrap.addCallback(self._state_complete)
+        state.post_bootstrap.addErrback(self._setup_failed)
 
     def _launch_tor(self):
         return launch_tor(self.tor_config, reactor,
-                          tor_binary=config.advanced.tor_binary,
+                          tor_binary=find_tor_binary(),
                           progress_updates=self._progress_updates,
                           stdout=self.tor_output,
                           timeout=self.timeout,
